==> tax-device-contract-model-1.1-20190715.112923-33-sources.jar: com/xforceplus/micro/tax/device/contract/model/QuerySqsStatusResponseQueueStatus.java <==
package com.xforceplus.micro.tax.device.contract.model;

import java.util.Objects;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import com.fasterxml.jackson.annotation.JsonInclude;
import static com.fasterxml.jackson.annotation.JsonInclude.Include.NON_NULL;
import com.fasterxml.jackson.annotation.JsonIgnore;
import java.io.Serializable;
import javax.validation.Valid;
import javax.validation.constraints.*;

/**
 * QuerySqsStatusResponseQueueStatus
 */

@JsonInclude(NON_NULL)
public class QuerySqsStatusResponseQueueStatus implements Serializable {
  private static final long serialVersionUID = 1L;

  @JsonProperty("account")
  private String account = null;

  @JsonProperty("directOnlineFlag")
  private Boolean directOnlineFlag = null;

  @JsonIgnore
  public QuerySqsStatusResponseQueueStatus account(String account) {
    this.account = account;
    return this;
  }

   /**
   * 账号
   * @return account
  **/


  @ApiModelProperty(value = "账号")
  public String getAccount() {
    return account;
  }

  public void setAccount(String account) {
    this.account = account;
  }

  @JsonIgnore
  public QuerySqsStatusResponseQueueStatus directOnlineFlag(Boolean directOnlineFlag) {
    this.directOnlineFlag = directOnlineFlag;
    return this;
  }

   /**
   * SQS直连在线标志,true:在线 false:不在线
   * @return directOnlineFlag
  **/


  @ApiModelProperty(value = "SQS直连在线标志,true:在线 false:不在线")
  public Boolean DirectOnlineFlag() {
    return directOnlineFlag;
  }

  public void setDirectOnlineFlag(Boolean directOnlineFlag) {
    this.directOnlineFlag = directOnlineFlag;
  }


  @Override
  public boolean equals(java.lang.Object o) {
    if (this == o) {
      return true;
    }
    if (o == null || getClass() != o.getClass()) {
      return false;
    }
    QuerySqsStatusResponseQueueStatus querySqsStatusResponseQueueStatus = (QuerySqsStatusResponseQueueStatus) o;
    return Objects.equals(this.account, querySqsStatusResponseQueueStatus.account) &&
        Objects.equals(this.directOnlineFlag, querySqsStatusResponseQueueStatus.directOnlineFlag);
  }

  @Override
  public int hashCode() {
    return Objects.hash(account, directOnlineFlag);
  }


  @Override
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("class QuerySqsStatusResponseQueueStatus {\n");
    
    sb.append("    account: ").append(toIndentedString(account)).append("\n");
    sb.append("    directOnlineFlag: ").append(toIndentedString(directOnlineFlag)).append("\n");
    sb.append("}");
    return sb.toString();
  }

  /**
   * Convert the given object to string with each line indented by 4 spaces
   * (except the first line).
   */
  private String toIndentedString(java.lang.Object o) {
    if (o == null) {
      return "null";
    }
    return o.toString().replace("\n", "\n    ");
  }

}

==> tax-device-contract-model-1.4-20210301.082130-90-sources.jar: com/xforceplus/micro/tax/device/contract/model/QuerySqsStatusResponseQueueStatus.java <==
package com.xforceplus.micro.tax.device.contract.model;

import java.util.Objects;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import com.fasterxml.jackson.annotation.JsonInclude;
import static com.fasterxml.jackson.annotation.JsonInclude.Include.NON_NULL;
import com.fasterxml.jackson.annotation.JsonIgnore;
import java.io.Serializable;
import javax.validation.Valid;
import javax.validation.constraints.*;

/**
 * QuerySqsStatusResponseQueueStatus
 */

@JsonInclude(NON_NULL)
public class QuerySqsStatusResponseQueueStatus implements Serializable {
  private static final long serialVersionUID = 1L;

  @JsonProperty("account")
  private String account = null;

  @JsonProperty("directOnlineFlag")
  private Boolean directOnlineFlag = null;

  @JsonProperty("sqsOriginAccountOnlineFlag")
  private Boolean sqsOriginAccountOnlineFlag = false;

  @JsonProperty("printerOnlineFlag")
  private Boolean printerOnlineFlag = false;

  @JsonIgnore
  public QuerySqsStatusResponseQueueStatus account(String account) {
    this.account = account;
    return this;
  }

   /**
   * 账号
   * @return account
  **/


  @ApiModelProperty(value = "账号")
  public String getAccount() {
    return account;
  }

  public void setAccount(String account) {
    this.account = account;
  }

  @JsonIgnore
  public QuerySqsStatusResponseQueueStatus directOnlineFlag(Boolean directOnlineFlag) {
    this.directOnlineFlag = directOnlineFlag;
    return this;
  }

   /**
   * SQS直连在线标志,true:在线 false:不在线
   * @return directOnlineFlag
  **/


  @ApiModelProperty(value = "SQS直连在线标志,true:在线 false:不在线")
  public Boolean DirectOnlineFlag() {
    return directOnlineFlag;
  }

  public void setDirectOnlineFlag(Boolean directOnlineFlag) {
    this.directOnlineFlag = directOnlineFlag;
  }

  @JsonIgnore
  public QuerySqsStatusResponseQueueStatus sqsOriginAccountOnlineFlag(Boolean sqsOriginAccountOnlineFlag) {
    this.sqsOriginAccountOnlineFlag = sqsOriginAccountOnlineFlag;
    return this;
  }

   /**
   * SQS抵账在线标志,true:在线 false:不在线
   * @return sqsOriginAccountOnlineFlag
  **/


  @ApiModelProperty(value = "SQS抵账在线标志,true:在线 false:不在线")
  public Boolean SqsOriginAccountOnlineFlag() {
    return sqsOriginAccountOnlineFlag;
  }

  public void setSqsOriginAccountOnlineFlag(Boolean sqsOriginAccountOnlineFlag) {
    this.sqsOriginAccountOnlineFlag = sqsOriginAccountOnlineFlag;
  }

  @JsonIgnore
  public QuerySqsStatusResponseQueueStatus printerOnlineFlag(Boolean printerOnlineFlag) {
    this.printerOnlineFlag = printerOnlineFlag;
    return this;
  }

   /**
   * 打印功能是否在线,true:在线 false:不在线
   * @return printerOnlineFlag
  **/


  @ApiModelProperty(value = "打印功能是否在线,true:在线 false:不在线")
  public Boolean PrinterOnlineFlag() {
    return printerOnlineFlag;
  }

  public void setPrinterOnlineFlag(Boolean printerOnlineFlag) {
    this.printerOnlineFlag = printerOnlineFlag;
  }


  @Override
  public boolean equals(java.lang.Object o) {
    if (this == o) {
      return true;
    }
    if (o == null || getClass() != o.getClass()) {
      return false;
    }
    QuerySqsStatusResponseQueueStatus querySqsStatusResponseQueueStatus = (QuerySqsStatusResponseQueueStatus) o;
    return Objects.equals(this.account, querySqsStatusResponseQueueStatus.account) &&
        Objects.equals(this.directOnlineFlag, querySqsStatusResponseQueueStatus.directOnlineFlag) &&
        Objects.equals(this.sqsOriginAccountOnlineFlag, querySqsStatusResponseQueueStatus.sqsOriginAccountOnlineFlag) &&
        Objects.equals(this.printerOnlineFlag, querySqsStatusResponseQueueStatus.printerOnlineFlag);
  }

  @Override
  public int hashCode() {
    return Objects.hash(account, directOnlineFlag, sqsOriginAccountOnlineFlag, printerOnlineFlag);
  }


  @Override
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("class QuerySqsStatusResponseQueueStatus {\n");
    
    sb.append("    account: ").append(toIndentedString(account)).append("\n");
    sb.append("    directOnlineFlag: ").append(toIndentedString(directOnlineFlag)).append("\n");
    sb.append("    sqsOriginAccountOnlineFlag: ").append(toIndentedString(sqsOriginAccountOnlineFlag)).append("\n");
    sb.append("    printerOnlineFlag: ").append(toIndentedString(printerOnlineFlag)).append("\n");
    sb.append("}");
    return sb.toString();
  }

  /**
   * Convert the given object to string with each line indented by 4 spaces
   * (except the first line).
   */
  private String toIndentedString(java.lang.Object o) {
    if (o == null) {
      return "null";
    }
    return o.toString().replace("\n", "\n    ");
  }

}
